summaryrefslogtreecommitdiff
path: root/transex3
diff options
context:
space:
mode:
authorKurt Zenker <kz@openoffice.org>2008-03-06 11:34:17 +0000
committerKurt Zenker <kz@openoffice.org>2008-03-06 11:34:17 +0000
commit388483d5d796c498b769e63508151d55f406f772 (patch)
tree025e87b2a13de490acce46d4e5c5cf1ccd683f0c /transex3
parent6137794a2f977a962862a53eb19cdfc4f2d71cf4 (diff)
INTEGRATION: CWS layout_DEV300 (1.12.92); FILE MERGED
2008/02/15 14:05:39 jcn 1.12.92.3: Further minimize diff. Revert now-unnecessary changes. 2008/02/15 13:51:54 jcn 1.12.92.2: Cleanup tralay, fixing shortcomings: any and all _-prefixed attributes are translated. 2008/02/11 15:33:48 jcn 1.12.92.1: Initial import into layout cws.
Diffstat (limited to 'transex3')
-rw-r--r--transex3/inc/xmlparse.hxx12
1 files changed, 7 insertions, 5 deletions
diff --git a/transex3/inc/xmlparse.hxx b/transex3/inc/xmlparse.hxx
index 282f9d4930bf..782c0db63b0e 100644
--- a/transex3/inc/xmlparse.hxx
+++ b/transex3/inc/xmlparse.hxx
@@ -4,9 +4,9 @@
*
* $RCSfile: xmlparse.hxx,v $
*
- * $Revision: 1.12 $
+ * $Revision: 1.13 $
*
- * last change: $Author: hr $ $Date: 2006-08-14 17:08:54 $
+ * last change: $Author: kz $ $Date: 2008-03-06 12:34:17 $
*
* The Contents of this file are made available subject to
* the terms of GNU Lesser General Public License Version 2.1.
@@ -232,7 +232,7 @@ public:
ByteString* GetGroupID(std::deque<ByteString> &groupid);
void Print( XMLNode *pCur = NULL, USHORT nLevel = 0 );
- void SearchL10NElements( XMLParentNode *pCur , int pos = 0);
+ virtual void SearchL10NElements( XMLParentNode *pCur, int pos = 0 );
void Extract( XMLFile *pCur = NULL );
void View();
// void static Signal_handler(int signo);//void*,oslSignalInfo * pInfo);
@@ -250,9 +250,10 @@ public:
/// returns file name
const String &GetName() { return sFileName; }
+ void SetName( const String &rFilename ) { sFileName = rFilename; }
const std::vector<ByteString> getOrder(){ return order; }
-private:
+protected:
// writes a string as UTF8 with dos line ends to a given stream
void WriteString( ofstream &rStream, const String &sString );
@@ -542,7 +543,8 @@ public:
/// parse a file, returns NULL on criticall errors
XMLFile *Execute(
- const String &rFileName // the file name
+ const String &rFileName, // the file name
+ XMLFile *pXMLFileIn // the XMLFile
);
/// parse a memory stream, returns NULL on criticall errors